process

package
v0.0.0-...-1cac2b9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	DefaultStore = NewStore()
)

Functions

func Annotations

func Annotations(ctx context.Context) []hydrant.Annotation

func MustRegisterAnnotation

func MustRegisterAnnotation(a ...hydrant.Annotation)

func MustRegisterOSAnnotations

func MustRegisterOSAnnotations(s *Store)

MustRegisterOSAnnotations is run on the default store at init.

func MustRegisterProcessAnnotations

func MustRegisterProcessAnnotations(s *Store)

MustRegisterProcessAnnotations is run on the default store at init.

func MustRegisterRuntimeAnnotations

func MustRegisterRuntimeAnnotations(s *Store)

MustRegisterRuntimeAnnotations is run on the default store at init.

func WithAnnotations

func WithAnnotations(ctx context.Context, s *Store) context.Context

Types

type Store

type Store struct {
	// contains filtered or unexported fields
}

func GetStore

func GetStore(ctx context.Context) *Store

func NewStore

func NewStore() *Store

func (*Store) Annotations

func (s *Store) Annotations() []hydrant.Annotation

func (*Store) MustRegisterAnnotation

func (s *Store) MustRegisterAnnotation(a ...hydrant.Annotation)

func (*Store) Select

func (s *Store) Select(fields []string) []hydrant.Annotation

Jump to