Documentation
¶
Index ¶
- Variables
- func Annotations(ctx context.Context) []hydrant.Annotation
- func MustRegisterAnnotation(a ...hydrant.Annotation)
- func MustRegisterOSAnnotations(s *Store)
- func MustRegisterProcessAnnotations(s *Store)
- func MustRegisterRuntimeAnnotations(s *Store)
- func WithAnnotations(ctx context.Context, s *Store) context.Context
- type Store
Constants ¶
This section is empty.
Variables ¶
var (
DefaultStore = NewStore()
)
Functions ¶
func Annotations ¶
func Annotations(ctx context.Context) []hydrant.Annotation
func MustRegisterAnnotation ¶
func MustRegisterAnnotation(a ...hydrant.Annotation)
func MustRegisterOSAnnotations ¶
func MustRegisterOSAnnotations(s *Store)
MustRegisterOSAnnotations is run on the default store at init.
func MustRegisterProcessAnnotations ¶
func MustRegisterProcessAnnotations(s *Store)
MustRegisterProcessAnnotations is run on the default store at init.
func MustRegisterRuntimeAnnotations ¶
func MustRegisterRuntimeAnnotations(s *Store)
MustRegisterRuntimeAnnotations is run on the default store at init.
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
func (*Store) Annotations ¶
func (s *Store) Annotations() []hydrant.Annotation
func (*Store) MustRegisterAnnotation ¶
func (s *Store) MustRegisterAnnotation(a ...hydrant.Annotation)
Click to show internal directories.
Click to hide internal directories.